import Bio.SeqIO
from Bio import Entrez

def fetch_seq(database, accession_number):
    """
    Retrieves a sequence from a public sequence database (such as NCBI) using its accession number.

    Parameters:
    database (str): The name of the database to search (e.g., 'nucleotide' for the NCBI nucleotide database).
    accession_number (str): The accession number of the sequence to retrieve.

    Returns:
    dict: A dictionary containing the sequence information, with keys 'id' and 'seq'.
    """
    # Provide your own email address to use for the Entrez search
    Entrez.email = 'sayaligrud@gmail.com'

    try:
        # Construct the query to search for the sequence with the specified accession number
        query = accession_number + '[Accession]'

        # Search the specified database for the sequence using the query
        handle = Entrez.esearch(db=database, term=query)
        record = Entrez.read(handle)
        handle.close()

        if not record['IdList']:
            raise ValueError(f"No sequence found for accession number {accession_number} in database {database}.")

        # Get the sequence record from the database using its ID
        sequence_id = record['IdList'][0]
        handle = Entrez.efetch(db=database, id=sequence_id, rettype='fasta', retmode='text')
        record = list(Bio.SeqIO.parse(handle, 'fasta'))[0]
        handle.close()

        # Return the sequence as a dictionary
        return {'id': str(record.id), 'seq': str(record.seq)}

    except Exception as e:
        print(f"Error occurred while fetching sequence for accession number {accession_number} in database {database}: {e}")
        return None
